| LinePlotAtomic | R Documentation |
Dispatcher that routes to LinePlotSingle or
LinePlotGrouped depending on whether group_by is
provided. Handles faceting via facet_plot() after the base
plot is built.
LinePlotAtomic(
data,
x,
y = NULL,
group_by = NULL,
fill_point_by_x_if_no_group = TRUE,
color_line_by_x_if_no_group = TRUE,
add_bg = FALSE,
bg_palette = "stripe",
bg_palcolor = NULL,
bg_alpha = 0.2,
add_errorbars = FALSE,
errorbar_width = 0.1,
errorbar_alpha = 1,
errorbar_color = "grey30",
errorbar_linewidth = 0.75,
errorbar_min = NULL,
errorbar_max = NULL,
errorbar_sd = NULL,
highlight = NULL,
highlight_size = pt_size - 0.75,
highlight_color = "red2",
highlight_alpha = 0.8,
pt_alpha = 1,
pt_size = 5,
add_hline = FALSE,
hline_type = "solid",
hline_width = 0.5,
hline_color = "black",
hline_alpha = 1,
line_type = "solid",
line_width = 1,
line_alpha = 0.8,
theme = "theme_this",
theme_args = list(),
palette = "Paired",
palcolor = NULL,
palreverse = FALSE,
x_text_angle = 0,
aspect.ratio = 1,
legend.position = "right",
legend.direction = "vertical",
title = NULL,
subtitle = NULL,
xlab = NULL,
ylab = NULL,
keep_empty = FALSE,
keep_na = FALSE,
facet_by = NULL,
facet_scales = "fixed",
facet_args = list(),
facet_nrow = NULL,
facet_ncol = NULL,
facet_byrow = TRUE,
...
)
data |
A data frame. |
x |
A character string specifying the column name for the x-axis. Must be character or factor. |
y |
A character string specifying the numeric column for the y-axis. |
group_by |
A character vector of column names to group the data by.
When NULL, a single-series line plot is drawn via
|
fill_point_by_x_if_no_group |
A logical value. When TRUE (default),
points are filled by the x-axis categories via the palette when
|
color_line_by_x_if_no_group |
A logical value. When TRUE (default),
lines are coloured by the x-axis categories via the palette when
|
add_bg |
A logical value. When TRUE, alternating background stripes
are drawn via |
bg_palette |
A character string specifying the palette for the
background stripe colours. Default |
bg_palcolor |
A character vector of colours for the background
stripes. When NULL (default), colours are derived from
|
bg_alpha |
A numeric value in |
add_errorbars |
A logical value. When TRUE, error bars are added via
|
errorbar_width |
A numeric value for the width of the error bar caps. Default 0.1. |
errorbar_alpha |
A numeric value in |
errorbar_color |
A character string for the colour of the error
bars. When |
errorbar_linewidth |
A numeric value for the line width of error bars. Default 0.75. |
errorbar_min |
A character string naming the column with the lower
error bar bound. Ignored when |
errorbar_max |
A character string naming the column with the upper
error bar bound. Ignored when |
errorbar_sd |
A character string naming the column with the standard
deviation. When |
highlight |
A vector of row indices, row names, a single string
expression (e.g. |
highlight_size |
A numeric value for the size of highlighted points.
Defaults to |
highlight_color |
A character string for the colour of highlighted
points. Default |
highlight_alpha |
A numeric value in |
pt_alpha |
A numeric value in |
pt_size |
A numeric value for the point size. Default 5. |
add_hline |
A numeric value specifying the y-intercept of a horizontal reference line. When FALSE (default), no line is drawn. |
hline_type |
A character string specifying the line type of the
horizontal reference line. Default |
hline_width |
A numeric value for the width of the horizontal reference line. Default 0.5. |
hline_color |
A character string for the colour of the horizontal
reference line. Default |
hline_alpha |
A numeric value in |
line_type |
A character string specifying the line type. Default
|
line_width |
A numeric value for the line width (in mm). Default 1. |
line_alpha |
A numeric value in |
theme |
A character string or a theme class (i.e. ggplot2::theme_classic) specifying the theme to use. Default is "theme_this". |
theme_args |
A list of arguments to pass to the theme function. |
palette |
A character string specifying the palette to use.
A named list or vector can be used to specify the palettes for different |
palcolor |
A character string specifying the color to use in the palette.
A named list can be used to specify the colors for different |
palreverse |
A logical value indicating whether to reverse the palette. Default is FALSE. |
x_text_angle |
A numeric value specifying the angle of the x-axis text. |
aspect.ratio |
A numeric value specifying the aspect ratio of the plot. |
legend.position |
A character string specifying the position of the legend.
if |
legend.direction |
A character string specifying the direction of the legend. |
title |
A character string specifying the title of the plot. A function can be used to generate the title based on the default title. This is useful when split_by is used and the title needs to be dynamic. |
subtitle |
A character string specifying the subtitle of the plot. |
xlab |
A character string specifying the x-axis label. |
ylab |
A character string specifying the y-axis label. |
keep_empty |
One of FALSE, TRUE and "level". It can also take a named list to specify
different behavior for different columns. Without a named list, the behavior applies to the
categorical/character columns used on the plot, for example, the
|
keep_na |
A logical value or a character to replace the NA values in the data.
It can also take a named list to specify different behavior for different columns.
If TRUE or NA, NA values will be replaced with NA.
If FALSE, NA values will be removed from the data before plotting.
If a character string is provided, NA values will be replaced with the provided string.
If a named vector/list is provided, the names should be the column names to apply the behavior to,
and the values should be one of TRUE, FALSE, or a character string.
Without a named vector/list, the behavior applies to categorical/character columns used on the plot,
for example, the |
facet_by |
A character string specifying the column name of the data frame to facet the plot.
Otherwise, the data will be split by |
facet_scales |
Whether to scale the axes of facets. Default is "fixed"
Other options are "free", "free_x", "free_y". See |
facet_args |
A list of additional arguments passed to
|
facet_nrow |
A numeric value specifying the number of rows in the facet. When facet_by is a single column and facet_wrap is used. |
facet_ncol |
A numeric value specifying the number of columns in the facet. When facet_by is a single column and facet_wrap is used. |
facet_byrow |
A logical value indicating whether to fill the plots by row. Default is TRUE. |
... |
Additional arguments. |
A ggplot object with height and width
attributes (in inches).
Column resolution – facet_by is validated via
check_columns.
Routing – when group_by = NULL, delegates to
LinePlotSingle (ungrouped, single-series line plot).
When group_by is provided, delegates to
LinePlotGrouped (multi-series line plot).
Facet keep_empty consistency – when facet_by
contains multiple columns, their keep_empty values must be
identical.
Faceting – facet_plot() applies
facet_wrap / facet_grid with the resolved
drop argument (derived from keep_empty).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.