This function blends a list of colors using the specified blend mode.
Usage
blend_colors(colors, mode = c("blend", "average", "screen", "multiply"))This function blends a list of colors using the specified blend mode.
blend_colors(colors, mode = c("blend", "average", "screen", "multiply"))