dot-check_annotation: Check the annotation specification The annotations should not...

.check_annotationR Documentation

Check the annotation specification The annotations should not be any of by or split_by, and the columns must exist in the data

Description

Check the annotation specification The annotations should not be any of by or split_by, and the columns must exist in the data

Usage

.check_annotation(data, annotation, by, split_by, which)

Arguments

data

The data for Heatmap plot

annotation

The annotation mappings

by

The column for rows or columns

split_by

The column for row or column splitting

which

If the annotation is for row or column


plotthis documentation built on June 10, 2026, 9:07 a.m.