| .apply_orderby | R Documentation |
Apply ordering to a data frame based on a specified expression
.apply_orderby(df, orderby, by, sby, sby_levels)
df |
A data frame to be ordered. |
orderby |
A character string representing the expression to order by. |
by |
A character string representing the column name to group by. |
sby |
A character string representing the column name to group by for secondary ordering. |
sby_levels |
A character vector representing the levels of the secondary grouping column. |
A data frame ordered based on the specified expression.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.