| .check_annotation | R Documentation |
Check the annotation specification The annotations should not be any of by or split_by, and the columns must exist in the data
.check_annotation(data, annotation, by, split_by, which)
data |
The data for Heatmap plot |
annotation |
The annotation mappings |
by |
The column for rows or columns |
split_by |
The column for row or column splitting |
which |
If the annotation is for row or column |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.