| .reorder_anno_side | R Documentation |
Reorder annotation list so split annotation (split_by) is farthest from heatmap body and name annotation (by) is closest. User annotations stay in between. For all annotation sides, ComplexHeatmap renders first-element = farthest, last-element = closest to the heatmap body.
.reorder_anno_side(x, by, split_by, side)
x |
A list of annotations |
by |
The name of the annotation used for row/column names |
split_by |
The name of the annotation used for splitting rows/columns |
side |
The annotation side ("top", "bottom", "left", "right") |
A reordered list of annotations
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.