| prepare_continuous_color_scale | R Documentation |
Computes the lower and upper cutoffs for a continuous color/fill scale,
applies data winsorization (clamping), and returns the results needed
by scale_fill_gradientn or
scale_color_gradientn.
prepare_continuous_color_scale(
data,
column,
lower_quantile = 0,
upper_quantile = 0.99,
lower_cutoff = NULL,
upper_cutoff = NULL,
bg_cutoff = NULL
)
data |
A data frame. |
column |
The column name in |
lower_quantile, upper_quantile |
Lower and upper quantiles for the continuous color/fill scale.
The actual cutoffs are determined by these quantiles when |
lower_cutoff, upper_cutoff |
Explicit lower and upper cutoffs for the continuous color/fill scale.
When |
bg_cutoff |
Optional numeric cutoff — values |
A list with components:
data |
The modified data frame (with winsorized |
feat_colors_value |
Numeric vector of 100 evenly-spaced values from
|
limits |
Numeric vector of length 2 giving the range
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.