| process_heatmap_data | R Documentation |
Heatmap()This function is used to process the data passed to Heatmap().
process_heatmap_data(
data,
in_form,
values_by,
name,
split_by,
split_by_sep,
rows_orderby,
columns_orderby,
rows_by,
rows_by_sep,
rows_name,
rows_split_by,
rows_split_by_sep,
rows_split_name,
columns_by,
columns_by_sep,
columns_name,
columns_split_by,
columns_split_by_sep,
columns_split_name,
pie_group_by,
pie_group_by_sep,
pie_name,
rows_data,
columns_data,
keep_na,
keep_empty
)
data |
A data frame or matrix containing the data to be plotted.
Based on the
|
in_form |
The format of the data. Can be one of |
values_by |
A character of column name in |
name |
A character string to name the heatmap (will be used to rename |
split_by |
A character of column name in |
split_by_sep |
A character string to concat multiple columns in |
rows_orderby |
A expression (in character) to specify how to order rows. It will be evaluated in the context of the data frame used for rows (after grouping by rows_split_by and rows_by). The expression should return a vector of the same length as the number of rows in the data frame. The default is NULL, which means no specific ordering. Can't be used with cluster_rows = TRUE. This is applied before renaming rows_by to rows_name. |
columns_orderby |
A expression (in character) to specify how to order columns. It will be evaluated in the context of the data frame used for columns (after grouping by columns split_by and columns_by). The expression should return a vector of the same length as the number of rows in the data frame. The default is NULL, which means no specific ordering. Can't be used with cluster_columns = TRUE. This is applied before renaming columns_by to columns_name. |
rows_by |
A vector of column names in |
rows_by_sep |
A character string to concat multiple columns in |
rows_name |
A character string to rename the column created by |
rows_split_by |
A character of column name in |
rows_split_by_sep |
A character string to concat multiple columns in |
rows_split_name |
A character string to rename the column created by |
columns_by |
A vector of column names in |
columns_by_sep |
A character string to concat multiple columns in |
columns_name |
A character string to rename the column created by |
columns_split_by |
A character of column name in |
columns_split_by_sep |
A character string to concat multiple columns in |
columns_split_name |
A character string to rename the column created by |
pie_group_by |
A character of column name in |
pie_group_by_sep |
A character string to concat multiple columns in |
pie_name |
A character string to rename the column created by |
rows_data |
A data frame containing additional data for rows, which can be used to add annotations to the heatmap.
It will be joined to the main data by |
columns_data |
A data frame containing additional data for columns, which can be used to add annotations to the heatmap.
It will be joined to the main data by |
keep_na |
Whether we should keep NA groups in rows, columns and split_by variables. Default is FALSE. FALSE to remove NA groups; TRUE to keep NA groups. A vector of column names can also be provided to specify which columns to keep NA groups. Note that the record will be removed if any of the grouping columns has NA and is not specified to keep NA. |
A list containing the processed data and metadata:
data: A list of data frames, one for each level of split_by. If no split_by is provided, the name will be "...".
Each data frame is in the long format.
values_by: The name of the column containing the values to be plotted.
rows_by: The name of the column containing the row information.
rows_split_by: The name of the column containing the row split information.
columns_by: The name of the column containing the column information.
columns_split_by: The name of the column containing the column split information.
pie_group_by: The name of the column containing the pie group information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.